==> Spire.Xls-13.9.0-py3-none-win_amd64.whl: spire/xls/XlsCheckBoxShape.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar,Union,Generic,List,Tuple
from spire.xls.common import *
from spire.xls import *
from ctypes import *
import abc

class XlsCheckBoxShape (  XlsShape, ICheckBox) :
    """

    """
    @property

    def CheckState(self)->'CheckState':
        """

        """
        GetDllLibXls().XlsCheckBoxShape_get_CheckState.argtypes=[c_void_p]
        GetDllLibXls().XlsCheckBoxShape_get_CheckState.restype=c_int
        ret = GetDllLibXls().XlsCheckBoxShape_get_CheckState(self.Ptr)
        objwraped = CheckState(ret)
        return objwraped

    @CheckState.setter
    def CheckState(self, value:'CheckState'):
        GetDllLibXls().XlsCheckBoxShape_set_CheckState.argtypes=[c_void_p, c_int]
        GetDllLibXls().XlsCheckBoxShape_set_CheckState(self.Ptr, value.value)

    @property

    def Text(self)->str:
        """

        """
        GetDllLibXls().XlsCheckBoxShape_get_Text.argtypes=[c_void_p]
        GetDllLibXls().XlsCheckBoxShape_get_Text.restype=c_void_p
        ret = PtrToStr(GetDllLibXls().XlsCheckBoxShape_get_Text(self.Ptr))
        return ret


    @Text.setter
    def Text(self, value:str):
        GetDllLibXls().XlsCheckBoxShape_set_Text.argtypes=[c_void_p, c_wchar_p]
        GetDllLibXls().XlsCheckBoxShape_set_Text(self.Ptr, value)

    @property
    def IsTextLocked(self)->bool:
        """

        """
        GetDllLibXls().XlsCheckBoxShape_get_IsTextLocked.argtypes=[c_void_p]
        GetDllLibXls().XlsCheckBoxShape_get_IsTextLocked.restype=c_bool
        ret = GetDllLibXls().XlsCheckBoxShape_get_IsTextLocked(self.Ptr)
        return ret

    @IsTextLocked.setter
    def IsTextLocked(self, value:bool):
        GetDllLibXls().XlsCheckBoxShape_set_IsTextLocked.argtypes=[c_void_p, c_bool]
        GetDllLibXls().XlsCheckBoxShape_set_IsTextLocked(self.Ptr, value)

    @property
    def Display3DShading(self)->bool:
        """

        """
        GetDllLibXls().XlsCheckBoxShape_get_Display3DShading.argtypes=[c_void_p]
        GetDllLibXls().XlsCheckBoxShape_get_Display3DShading.restype=c_bool
        ret = GetDllLibXls().XlsCheckBoxShape_get_Display3DShading(self.Ptr)
        return ret

    @Display3DShading.setter
    def Display3DShading(self, value:bool):
        GetDllLibXls().XlsCheckBoxShape_set_Display3DShading.argtypes=[c_void_p, c_bool]
        GetDllLibXls().XlsCheckBoxShape_set_Display3DShading(self.Ptr, value)

    @property

    def ShapeType(self)->'ExcelShapeType':
        """

        """
        GetDllLibXls().XlsCheckBoxShape_get_ShapeType.argtypes=[c_void_p]
        GetDllLibXls().XlsCheckBoxShape_get_ShapeType.restype=c_int
        ret = GetDllLibXls().XlsCheckBoxShape_get_ShapeType(self.Ptr)
        objwraped = ExcelShapeType(ret)
        return objwraped

    @property

    def HAlignment(self)->'CommentHAlignType':
        """

        """
        GetDllLibXls().XlsCheckBoxShape_get_HAlignment.argtypes=[c_void_p]
        GetDllLibXls().XlsCheckBoxShape_get_HAlignment.restype=c_int
        ret = GetDllLibXls().XlsCheckBoxShape_get_HAlignment(self.Ptr)
        objwraped = CommentHAlignType(ret)
        return objwraped

    @HAlignment.setter
    def HAlignment(self, value:'CommentHAlignType'):
        GetDllLibXls().XlsCheckBoxShape_set_HAlignment.argtypes=[c_void_p, c_int]
        GetDllLibXls().XlsCheckBoxShape_set_HAlignment(self.Ptr, value.value)

    @property

    def VAlignment(self)->'CommentVAlignType':
        """

        """
        GetDllLibXls().XlsCheckBoxShape_get_VAlignment.argtypes=[c_void_p]
        GetDllLibXls().XlsCheckBoxShape_get_VAlignment.restype=c_int
        ret = GetDllLibXls().XlsCheckBoxShape_get_VAlignment(self.Ptr)
        objwraped = CommentVAlignType(ret)
        return objwraped

    @VAlignment.setter
    def VAlignment(self, value:'CommentVAlignType'):
        GetDllLibXls().XlsCheckBoxShape_set_VAlignment.argtypes=[c_void_p, c_int]
        GetDllLibXls().XlsCheckBoxShape_set_VAlignment(self.Ptr, value.value)

    @property

    def TextRotation(self)->'TextRotationType':
        """

        """
        GetDllLibXls().XlsCheckBoxShape_get_TextRotation.argtypes=[c_void_p]
        GetDllLibXls().XlsCheckBoxShape_get_TextRotation.restype=c_int
        ret = GetDllLibXls().XlsCheckBoxShape_get_TextRotation(self.Ptr)
        objwraped = TextRotationType(ret)
        return objwraped

    @TextRotation.setter
    def TextRotation(self, value:'TextRotationType'):
        GetDllLibXls().XlsCheckBoxShape_set_TextRotation.argtypes=[c_void_p, c_int]
        GetDllLibXls().XlsCheckBoxShape_set_TextRotation(self.Ptr, value.value)

#
#    def Clone(self ,parent:'SpireObject',hashNewNames:'Dictionary2',dicFontIndexes:'Dictionary2',addToCollections:bool)->'IShape':
#        """
#
#        """
#        intPtrparent:c_void_p = parent.Ptr
#        intPtrhashNewNames:c_void_p = hashNewNames.Ptr
#        intPtrdicFontIndexes:c_void_p = dicFontIndexes.Ptr
#
#        GetDllLibXls().XlsCheckBoxShape_Clone.argtypes=[c_void_p ,c_void_p,c_void_p,c_void_p,c_bool]
#        GetDllLibXls().XlsCheckBoxShape_Clone.restype=c_void_p
#        intPtr = GetDllLibXls().XlsCheckBoxShape_Clone(self.Ptr, intPtrparent,intPtrhashNewNames,intPtrdicFontIndexes,addToCollections)
#        ret = None if intPtr==None else IShape(intPtr)
#        return ret
#

==> Spire.Xls-14.4.4-py3-none-win_amd64.whl: spire/xls/XlsCheckBoxShape.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar,Union,Generic,List,Tuple
from spire.xls.common import *
from spire.xls import *
from ctypes import *
import abc

class XlsCheckBoxShape (  XlsShape, ICheckBox) :
    """

    """
    @property

    def CheckState(self)->'CheckState':
        """

        """
        GetDllLibXls().XlsCheckBoxShape_get_CheckState.argtypes=[c_void_p]
        GetDllLibXls().XlsCheckBoxShape_get_CheckState.restype=c_int
        ret = CallCFunction(GetDllLibXls().XlsCheckBoxShape_get_CheckState, self.Ptr)
        objwraped = CheckState(ret)
        return objwraped

    @CheckState.setter
    def CheckState(self, value:'CheckState'):
        GetDllLibXls().XlsCheckBoxShape_set_CheckState.argtypes=[c_void_p, c_int]
        CallCFunction(GetDllLibXls().XlsCheckBoxShape_set_CheckState, self.Ptr, value.value)

    @property

    def Text(self)->str:
        """

        """
        GetDllLibXls().XlsCheckBoxShape_get_Text.argtypes=[c_void_p]
        GetDllLibXls().XlsCheckBoxShape_get_Text.restype=c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibXls().XlsCheckBoxShape_get_Text, self.Ptr))
        return ret


    @Text.setter
    def Text(self, value:str):
        GetDllLibXls().XlsCheckBoxShape_set_Text.argtypes=[c_void_p, c_wchar_p]
        CallCFunction(GetDllLibXls().XlsCheckBoxShape_set_Text, self.Ptr, value)

    @property
    def IsTextLocked(self)->bool:
        """

        """
        GetDllLibXls().XlsCheckBoxShape_get_IsTextLocked.argtypes=[c_void_p]
        GetDllLibXls().XlsCheckBoxShape_get_IsTextLocked.restype=c_bool
        ret = CallCFunction(GetDllLibXls().XlsCheckBoxShape_get_IsTextLocked, self.Ptr)
        return ret

    @IsTextLocked.setter
    def IsTextLocked(self, value:bool):
        GetDllLibXls().XlsCheckBoxShape_set_IsTextLocked.argtypes=[c_void_p, c_bool]
        CallCFunction(GetDllLibXls().XlsCheckBoxShape_set_IsTextLocked, self.Ptr, value)

    @property
    def Display3DShading(self)->bool:
        """

        """
        GetDllLibXls().XlsCheckBoxShape_get_Display3DShading.argtypes=[c_void_p]
        GetDllLibXls().XlsCheckBoxShape_get_Display3DShading.restype=c_bool
        ret = CallCFunction(GetDllLibXls().XlsCheckBoxShape_get_Display3DShading, self.Ptr)
        return ret

    @Display3DShading.setter
    def Display3DShading(self, value:bool):
        GetDllLibXls().XlsCheckBoxShape_set_Display3DShading.argtypes=[c_void_p, c_bool]
        CallCFunction(GetDllLibXls().XlsCheckBoxShape_set_Display3DShading, self.Ptr, value)

    @property

    def ShapeType(self)->'ExcelShapeType':
        """

        """
        GetDllLibXls().XlsCheckBoxShape_get_ShapeType.argtypes=[c_void_p]
        GetDllLibXls().XlsCheckBoxShape_get_ShapeType.restype=c_int
        ret = CallCFunction(GetDllLibXls().XlsCheckBoxShape_get_ShapeType, self.Ptr)
        objwraped = ExcelShapeType(ret)
        return objwraped

    @property

    def HAlignment(self)->'CommentHAlignType':
        """

        """
        GetDllLibXls().XlsCheckBoxShape_get_HAlignment.argtypes=[c_void_p]
        GetDllLibXls().XlsCheckBoxShape_get_HAlignment.restype=c_int
        ret = CallCFunction(GetDllLibXls().XlsCheckBoxShape_get_HAlignment, self.Ptr)
        objwraped = CommentHAlignType(ret)
        return objwraped

    @HAlignment.setter
    def HAlignment(self, value:'CommentHAlignType'):
        GetDllLibXls().XlsCheckBoxShape_set_HAlignment.argtypes=[c_void_p, c_int]
        CallCFunction(GetDllLibXls().XlsCheckBoxShape_set_HAlignment, self.Ptr, value.value)

    @property

    def VAlignment(self)->'CommentVAlignType':
        """

        """
        GetDllLibXls().XlsCheckBoxShape_get_VAlignment.argtypes=[c_void_p]
        GetDllLibXls().XlsCheckBoxShape_get_VAlignment.restype=c_int
        ret = CallCFunction(GetDllLibXls().XlsCheckBoxShape_get_VAlignment, self.Ptr)
        objwraped = CommentVAlignType(ret)
        return objwraped

    @VAlignment.setter
    def VAlignment(self, value:'CommentVAlignType'):
        GetDllLibXls().XlsCheckBoxShape_set_VAlignment.argtypes=[c_void_p, c_int]
        CallCFunction(GetDllLibXls().XlsCheckBoxShape_set_VAlignment, self.Ptr, value.value)

    @property

    def TextRotation(self)->'TextRotationType':
        """

        """
        GetDllLibXls().XlsCheckBoxShape_get_TextRotation.argtypes=[c_void_p]
        GetDllLibXls().XlsCheckBoxShape_get_TextRotation.restype=c_int
        ret = CallCFunction(GetDllLibXls().XlsCheckBoxShape_get_TextRotation, self.Ptr)
        objwraped = TextRotationType(ret)
        return objwraped

    @TextRotation.setter
    def TextRotation(self, value:'TextRotationType'):
        GetDllLibXls().XlsCheckBoxShape_set_TextRotation.argtypes=[c_void_p, c_int]
        CallCFunction(GetDllLibXls().XlsCheckBoxShape_set_TextRotation, self.Ptr, value.value)

#
#    def Clone(self ,parent:'SpireObject',hashNewNames:'Dictionary2',dicFontIndexes:'Dictionary2',addToCollections:bool)->'IShape':
#        """
#
#        """
#        intPtrparent:c_void_p = parent.Ptr
#        intPtrhashNewNames:c_void_p = hashNewNames.Ptr
#        intPtrdicFontIndexes:c_void_p = dicFontIndexes.Ptr
#
#        GetDllLibXls().XlsCheckBoxShape_Clone.argtypes=[c_void_p ,c_void_p,c_void_p,c_void_p,c_bool]
#        GetDllLibXls().XlsCheckBoxShape_Clone.restype=c_void_p
#        intPtr = CallCFunction(GetDllLibXls().XlsCheckBoxShape_Clone, self.Ptr, intPtrparent,intPtrhashNewNames,intPtrdicFontIndexes,addToCollections)
#        ret = None if intPtr==None else IShape(intPtr)
#        return ret
#
